==> pnm2ppa_1.04.orig.tar.gz: pnm2ppa-1.04.orig/text-cz.h <==
/***************************************************************************
    text-cs.h  -  contains the czech strings
                             -------------------
    begin                : Thu Jan 13 2000
    copyright            : (C) 2000 by Andrew van der Stock
    email                : ajv@greebo.net
    translator           : Ivo Panacek <ivop@regionet.cz>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/* messages from cutswath.c */

/* 00 */ "nemohu alokovat dal pam\n",
  
  /* 01 */ "nemohu pest velikost hornho okraje\n",
  
  /* 02 */ "nemohu pest velikost spodnho okraje\n",
  
  /* 03 */ "nemohu pest dal dku\n",
  
  /* 04 */ "nemohu alokovat pam pro ppa\n",
  
  /* 05 */ "chyba pi voln",   //followed by function name
  
  /* 06 */ "neznm nvratov hodnota pepnae\n",
  
  // from ppa,c

  /* 07 */ "zkracuji data pro trysky na 6 dek, (pvodn ", // followed by number
  
  // messages from image.c
  
  /* 08 */ "Nemohu vytvoit gamma.ppm soubor. Zkontrolujte prva\n",
  
  /* 09 */ "Pedasn ukonen vstup - narazil jsem na EOF pi ten obrzku:", //followed by format
  
  /* 10 */ "Fatln chyba - nemohu st obrzek\n",
  
  /* 11 */ "Fatln chyba - vstupn obrzek obsahuje pixl s hodnotou > 255\n",
  
  /* 12 */ "Fatln chyba! Nemohu alokovat pam pro buffer!\n",
  
  /* 13 */ "Vstupn obrzek nem podporovan PNM formt\n",
  
  /* 14 */  // (removed)
  
  /* 15 */ "Tiskrna neme tisknout na papr velikosti ", //followed by size 
  
  /* 16 */ "maximln hodnota PNM pixlu mus bt 255, ale je: ", //followed by value
  
  // messages from ppa.c and pnm2ppa.c
  
  /* 17 */ "Neznm verze tiskrny\n",   
  
  /* 18 */ "Nemohu alokovat prostor pro uloen komprimovanch dat\n",
  
  /* 19 */ "Zanm zpracovvat tiskovou lohu\n",
  
  /* 20 */ "Tisknu strnku ", //followed by page number
  
  /* 21 */ "Konec zpracovn strnky ",  //followed by page number
  
  /* 22 */ "dn strnky nebyly vytitny!\n",
  
  /* 23 */ "Tiskov loha dopadla spn.\n",
  
  /* 24 */ "Upovdan vpis na konzoli\n",
  
  /* 25 */ "Prosm, nastavte si tiskrnu v souboru /etc/pnm2ppa.conf\n",
  
  /* 26 */ "nemohu otevt konfiguranho soubor\n", 

  /* 27 */ "neznm velikost papru\n", 

  /* 28 */ "neznm parametr", // not followed by \n

  /* 29 */ "na dce", // followed by line number 

  /* 30 */  "chyba pi ten konfiguranho souboru",  // not followed  by \n

  /* 31 */ "Fatln chyba: neznm argument\n" ,  

  /* 32 */ "Nemohu otevt vstupn PPA soubor\n", 
  
  /* 33 */ "Nemohu otevt vstupn PPA soubor\n",

  /* 34 */ "verze a datum pekladu:", //followed by version number and date

  /* 35 */ "Color correction curve (Gamma) file exists, but is corrupt.\n",

  /* 36 */ "POSSIBLE BUFFER OVERFLOW ATTACK!!: length of a path specified as an option exceeds", //followed by maximum allowed size

    "FATAL: patn chybov hlen\n"

==> pnm2ppa_1.13.orig.tar.gz: pnm2ppa-1.13/text-cz.h <==
/***************************************************************************
    text-cs.h  -  contains the czech strings
                             -------------------
    begin                : Thu Jan 13 2000
    copyright            : (C) 2000 by Andrew van der Stock
    email                : ajv@greebo.net
    translator           : Ivo Panacek <ivop@regionet.cz>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/* messages from cutswath.c */

/* 00 */ "nemohu alokovat dal pam\n",
  
  /* 01 */ "nemohu pest velikost hornho okraje\n",
  
  /* 02 */ "nemohu pest velikost spodnho okraje\n",
  
  /* 03 */ "nemohu pest dal dku\n",
  
  /* 04 */ "nemohu alokovat pam pro ppa\n",
  
  /* 05 */ "chyba pi voln",   /*followed by function name*/
  
  /* 06 */ "neznm nvratov hodnota pepnae\n",
  
  /* from ppa.c */

  /* 07 */ "zkracuji data pro trysky na 6 dek, (pvodn ", /* followed by number */
  
  /* messages from image.c */
  
  /* 08 */ "Nemohu vytvoit gamma.ppm soubor. Zkontrolujte prva\n",
  
  /* 09 */ "Pedasn ukonen vstup - narazil jsem na EOF pi ten obrzku:", /*followed by format*/
  
  /* 10 */ "Fatln chyba - nemohu st obrzek\n",
  
  /* 11 */ "Fatln chyba - vstupn obrzek obsahuje pixl s hodnotou > 255\n",
  
  /* 12 */ "Fatln chyba! Nemohu alokovat pam pro buffer!\n",
  
  /* 13 */ "Fatln chyba! Vstupn obrzek (pnm2ppa) nem PNM formt\n",
  
  /* 14 */  /* (removed) */
  
  /* 15 */ "Tiskrna neme tisknout na papr velikosti ", /*followed by size*/
  
  /* 16 */ "maximln hodnota PNM pixlu mus bt 255, ale je: ", /*followed by value */
  
  /* messages from ppa.c and pnm2ppa.c */
  
  /* 17 */ "Neznm verze tiskrny\n",   
  
  /* 18 */ "Nemohu alokovat prostor pro uloen komprimovanch dat\n",
  
  /* 19 */ "Zanm zpracovvat tiskovou lohu\n",
  
  /* 20 */ "Tisknu strnku ", /*followed by page number*/
  
  /* 21 */ "Konec zpracovn strnky ",  /*followed by page number*/
  
  /* 22 */ "dn strnky nebyly vytitny!\n",
  
  /* 23 */ "Tiskov loha dopadla spn.\n",
  
  /* 24 */ "Upovdan vpis na konzoli\n",
  
  /* 25 */ "Prosm, nastavte si tiskrnu v souboru /etc/pnm2ppa.conf\n",
  
  /* 26 */ "nemohu otevt konfiguranho soubor\n", 

  /* 27 */ "neznm velikost papru\n", 

  /* 28 */ "neznm parametr", /* not followed by \n */

  /* 29 */ "na dce", /* followed by line number */

  /* 30 */  "chyba pi ten konfiguranho souboru",  /* not followed  by \n */

  /* 31 */ "Fatln chyba: neznm argument\n" ,  

  /* 32 */ "Nemohu otevt vstupn PPA soubor\n", 
  
  /* 33 */ "Nemohu otevt vstupn PPA soubor\n",

  /* 34 */ "verze a datum pekladu:", /*followed by version number and date*/

  /* 35 */ "Color correction curve (Gamma) file exists, but is corrupt.\n",

  /* 36 */ "POSSIBLE BUFFER OVERFLOW ATTACK!!: length of a path specified as an option exceeds", /*followed by maximum allowed size*/

    "FATAL: patn chybov hlen\n"
